/*
 * LiPo Tester - Li-Ion capacity tester
 *
 * ports.h - hardware definition
 *
 * (c) Axel (XL) Schwenke, axel.schwenke@gmx.net
 *
 * $Id: ports.h 315 2016-03-03 12:00:24Z schwenke $
 */

#ifndef PORTS_H
#define PORTS_H

/*

Arduino        ATMEGA328         Arduino
::         ------------------         ::
::    ISP |Res            PC5| DB5....A5
D0....RxD |PD0            PC4| DB4....A4
D1....TxD |PD1            PC3| DB3....A3
D2....... |PD2            PC2| DB2....A2
D3....... |PD3            PC1| DB1....A1
D4....... |PD4            PC0| DB0....A0
::    +5V |Vcc            GND| GND    ::
::    GND |GND           ARef|        ::
::        |XTAL1         AVcc| +5V    ::
::        |XTAL2      SCK/PB5| ISP....D13 = User LED
D5....... |PD5       MISO/PB4| ISP....D12 = Discharge
D6....DB6 |PD6       MOSI/PB3| ISP....D11
D7....DB7 |PD7            PB2| E......D10
D8....RS  |PB0/ICP1       PB1| RW.....D9
           ------------------

DB0 - DB7 .... Data Bus for LCD
RS, R/W, E ... LCD control lines
RxD, TxD ..... RS-232
ISP .......... to ISP connector

*/

#define LCD_LINES     2         /* this is a 2x16 display   */
#define LCD_DISP_LEN  16

#define LCD_CTRL_PORT    PORTB  /* port for control lines   */
#define LCD_RS_PIN       0      /* pin  for RS line         */
#define LCD_RW_PIN       1      /* pin  for RW line         */
#define LCD_E_PIN        2      /* pin  for Enable line     */

#define lcd_e_high()     LCD_CTRL_PORT |=  _BV(LCD_E_PIN)
#define lcd_e_low()      LCD_CTRL_PORT &= ~_BV(LCD_E_PIN)
#define lcd_rw_high()    LCD_CTRL_PORT |=  _BV(LCD_RW_PIN)
#define lcd_rw_low()     LCD_CTRL_PORT &= ~_BV(LCD_RW_PIN)
#define lcd_rs_high()    LCD_CTRL_PORT |=  _BV(LCD_RS_PIN)
#define lcd_rs_low()     LCD_CTRL_PORT &= ~_BV(LCD_RS_PIN)

#define data_output()    DDRC |=  0x3F; DDRD |=  0xC0
#define data_input()     DDRC &= ~0x3F; DDRD &= ~0xC0
#define data_write(x)    PORTC = (PORTC & ~0x3F) | ((x) & 0x3F); \
                         PORTD = (PORTD & ~0xC0) | ((x) & 0xC0)
#define data_read()      ((PINC & 0x3F) | (PIND & 0xC0))

#define LED_PIN          5
#define LED_on()         PORTB |=  _BV(LED_PIN)
#define LED_off()        PORTB &= ~_BV(LED_PIN)
#define LED_toggle()     PORTB ^=  _BV(LED_PIN)

#define DISCHARGE_PIN    4
#define DISCHARGE_on()   PORTB |=  _BV(DISCHARGE_PIN)
#define DISCHARGE_off()  PORTB &= ~_BV(DISCHARGE_PIN)

#endif
